"""
Created on Thu Nov 2023
Author: Arseniy Burov (Skoltech)
Note: Make a PES plot for conformers

"""
from os import listdir
from os.path import isfile, join
import matplotlib.pyplot as plt
from scipy import interpolate
import numpy as np

"""
example of use: 
>>> python3 make_plot.py
"""

log_files = [file for file in listdir("./") if isfile(join("./", file)) and ("log" in file) and ("lammps" not in file)]
dehidral_list = [ 180-float(val.split("_")[-1]) for val in log_files ]
dehidral_list, log_files = zip(*sorted(zip(dehidral_list, log_files)))

en_list = []

for file in log_files:
	with open(file, "r") as f:
		lines = f.readlines()

	for line in lines:
		if ("Final potential energy" in line) and ("$" not in line):
			en_list.append( float(line.split()[-1])*23.06035  )   # 23.06035 kcal/mol to eV 

### Fit dehidrals and energies
f = interpolate.splrep(dehidral_list, en_list)
xnew = np.linspace(dehidral_list[0], dehidral_list[-1], 200)
ynew = interpolate.splev(xnew, f)


fig, ax = plt.subplots()
fig.set_size_inches(6, 6)
fig.tight_layout()
ax.set_xlabel(r'Dihedral', fontsize=20)
ax.set_ylabel(r'Energy (meV) ', fontsize=20)
ax.tick_params(axis='both', which='major', labelsize=14)
ax.yaxis.set_major_locator(plt.MaxNLocator(6))

ax.scatter(dehidral_list, en_list)
ax.plot(xnew, ynew, "-", c="r")

# plt.show()
fig.savefig('./pes_dehidral.png', dpi=600, bbox_inches='tight')

